@@ -36,7 +36,9 @@ __all__ = (
     "RelevanceLevelType",
     "SearchContentPaginatorName",
     "SearchSessionsPaginatorName",
+    "ConnectWisdomServiceServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -79,6 +81,7 @@ QueryAssistantPaginatorName = Literal["query_assistant"]
 RelevanceLevelType = Literal["HIGH", "LOW", "MEDIUM"]
 SearchContentPaginatorName = Literal["search_content"]
 SearchSessionsPaginatorName = Literal["search_sessions"]
+ConnectWisdomServiceServiceName = Literal["wisdom"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -110,6 +113,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -232,6 +236,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -380,6 +385,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_assistant_associations",
     "list_assistants",
