@@ -1,7 +1,7 @@
 """
 Type annotations for wisdom service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/type_defs.html)
 
 Usage::
 
@@ -81,16 +81,12 @@ __all__ = (
     "KnowledgeBaseAssociationDataTypeDef",
     "KnowledgeBaseDataTypeDef",
     "KnowledgeBaseSummaryTypeDef",
-    "ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
     "ListAssistantAssociationsRequestRequestTypeDef",
     "ListAssistantAssociationsResponseTypeDef",
-    "ListAssistantsRequestListAssistantsPaginateTypeDef",
     "ListAssistantsRequestRequestTypeDef",
     "ListAssistantsResponseTypeDef",
-    "ListContentsRequestListContentsPaginateTypeDef",
     "ListContentsRequestRequestTypeDef",
     "ListContentsResponseTypeDef",
-    "ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef",
     "ListKnowledgeBasesRequestRequestTypeDef",
     "ListKnowledgeBasesResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -99,7 +95,6 @@ __all__ = (
     "NotifyRecommendationsReceivedRequestRequestTypeDef",
     "NotifyRecommendationsReceivedResponseTypeDef",
     "PaginatorConfigTypeDef",
-    "QueryAssistantRequestQueryAssistantPaginateTypeDef",
     "QueryAssistantRequestRequestTypeDef",
     "QueryAssistantResponseTypeDef",
     "RecommendationDataTypeDef",
@@ -108,11 +103,9 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "ResultDataTypeDef",
     "SearchContentRequestRequestTypeDef",
-    "SearchContentRequestSearchContentPaginateTypeDef",
     "SearchContentResponseTypeDef",
     "SearchExpressionTypeDef",
     "SearchSessionsRequestRequestTypeDef",
-    "SearchSessionsRequestSearchSessionsPaginateTypeDef",
     "SearchSessionsResponseTypeDef",
     "ServerSideEncryptionConfigurationTypeDef",
     "SessionDataTypeDef",
@@ -136,8 +129,8 @@ AppIntegrationsConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredAssistantAssociationDataTypeDef = TypedDict(
-    "_RequiredAssistantAssociationDataTypeDef",
+AssistantAssociationDataTypeDef = TypedDict(
+    "AssistantAssociationDataTypeDef",
     {
         "assistantArn": str,
         "assistantAssociationArn": str,
@@ -145,41 +138,26 @@ _RequiredAssistantAssociationDataTypeDef = TypedDict(
         "assistantId": str,
         "associationData": "AssistantAssociationOutputDataTypeDef",
         "associationType": Literal["KNOWLEDGE_BASE"],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalAssistantAssociationDataTypeDef = TypedDict(
-    "_OptionalAssistantAssociationDataTypeDef",
-    {
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class AssistantAssociationDataTypeDef(
-    _RequiredAssistantAssociationDataTypeDef, _OptionalAssistantAssociationDataTypeDef
-):
-    pass
-
 
 AssistantAssociationInputDataTypeDef = TypedDict(
     "AssistantAssociationInputDataTypeDef",
     {
-        "knowledgeBaseId": str,
+        "knowledgeBaseId": NotRequired[str],
     },
-    total=False,
 )
 
 AssistantAssociationOutputDataTypeDef = TypedDict(
     "AssistantAssociationOutputDataTypeDef",
     {
-        "knowledgeBaseAssociation": "KnowledgeBaseAssociationDataTypeDef",
+        "knowledgeBaseAssociation": NotRequired["KnowledgeBaseAssociationDataTypeDef"],
     },
-    total=False,
 )
 
-_RequiredAssistantAssociationSummaryTypeDef = TypedDict(
-    "_RequiredAssistantAssociationSummaryTypeDef",
+AssistantAssociationSummaryTypeDef = TypedDict(
+    "AssistantAssociationSummaryTypeDef",
     {
         "assistantArn": str,
         "assistantAssociationArn": str,
@@ -187,75 +165,44 @@ _RequiredAssistantAssociationSummaryTypeDef = TypedDict(
         "assistantId": str,
         "associationData": "AssistantAssociationOutputDataTypeDef",
         "associationType": Literal["KNOWLEDGE_BASE"],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalAssistantAssociationSummaryTypeDef = TypedDict(
-    "_OptionalAssistantAssociationSummaryTypeDef",
-    {
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
 
-
-class AssistantAssociationSummaryTypeDef(
-    _RequiredAssistantAssociationSummaryTypeDef, _OptionalAssistantAssociationSummaryTypeDef
-):
-    pass
-
-
-_RequiredAssistantDataTypeDef = TypedDict(
-    "_RequiredAssistantDataTypeDef",
+AssistantDataTypeDef = TypedDict(
+    "AssistantDataTypeDef",
     {
         "assistantArn": str,
         "assistantId": str,
         "name": str,
         "status": AssistantStatusType,
         "type": Literal["AGENT"],
+        "description": NotRequired[str],
+        "serverSideEncryptionConfiguration": NotRequired[
+            "ServerSideEncryptionConfigurationTypeDef"
+        ],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalAssistantDataTypeDef = TypedDict(
-    "_OptionalAssistantDataTypeDef",
-    {
-        "description": str,
-        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
 
-
-class AssistantDataTypeDef(_RequiredAssistantDataTypeDef, _OptionalAssistantDataTypeDef):
-    pass
-
-
-_RequiredAssistantSummaryTypeDef = TypedDict(
-    "_RequiredAssistantSummaryTypeDef",
+AssistantSummaryTypeDef = TypedDict(
+    "AssistantSummaryTypeDef",
     {
         "assistantArn": str,
         "assistantId": str,
         "name": str,
         "status": AssistantStatusType,
         "type": Literal["AGENT"],
+        "description": NotRequired[str],
+        "serverSideEncryptionConfiguration": NotRequired[
+            "ServerSideEncryptionConfigurationTypeDef"
+        ],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalAssistantSummaryTypeDef = TypedDict(
-    "_OptionalAssistantSummaryTypeDef",
-    {
-        "description": str,
-        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
 
-
-class AssistantSummaryTypeDef(_RequiredAssistantSummaryTypeDef, _OptionalAssistantSummaryTypeDef):
-    pass
-
-
-_RequiredContentDataTypeDef = TypedDict(
-    "_RequiredContentDataTypeDef",
+ContentDataTypeDef = TypedDict(
+    "ContentDataTypeDef",
     {
         "contentArn": str,
         "contentId": str,
@@ -269,35 +216,23 @@ _RequiredContentDataTypeDef = TypedDict(
         "title": str,
         "url": str,
         "urlExpiry": datetime,
+        "linkOutUri": NotRequired[str],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalContentDataTypeDef = TypedDict(
-    "_OptionalContentDataTypeDef",
-    {
-        "linkOutUri": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class ContentDataTypeDef(_RequiredContentDataTypeDef, _OptionalContentDataTypeDef):
-    pass
-
 
 ContentReferenceTypeDef = TypedDict(
     "ContentReferenceTypeDef",
     {
-        "contentArn": str,
-        "contentId": str,
-        "knowledgeBaseArn": str,
-        "knowledgeBaseId": str,
+        "contentArn": NotRequired[str],
+        "contentId": NotRequired[str],
+        "knowledgeBaseArn": NotRequired[str],
+        "knowledgeBaseId": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredContentSummaryTypeDef = TypedDict(
-    "_RequiredContentSummaryTypeDef",
+ContentSummaryTypeDef = TypedDict(
+    "ContentSummaryTypeDef",
     {
         "contentArn": str,
         "contentId": str,
@@ -309,45 +244,20 @@ _RequiredContentSummaryTypeDef = TypedDict(
         "revisionId": str,
         "status": ContentStatusType,
         "title": str,
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalContentSummaryTypeDef = TypedDict(
-    "_OptionalContentSummaryTypeDef",
-    {
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
 
-
-class ContentSummaryTypeDef(_RequiredContentSummaryTypeDef, _OptionalContentSummaryTypeDef):
-    pass
-
-
-_RequiredCreateAssistantAssociationRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAssistantAssociationRequestRequestTypeDef",
+CreateAssistantAssociationRequestRequestTypeDef = TypedDict(
+    "CreateAssistantAssociationRequestRequestTypeDef",
     {
         "assistantId": str,
         "association": "AssistantAssociationInputDataTypeDef",
         "associationType": Literal["KNOWLEDGE_BASE"],
+        "clientToken": NotRequired[str],
+        "tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateAssistantAssociationRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAssistantAssociationRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateAssistantAssociationRequestRequestTypeDef(
-    _RequiredCreateAssistantAssociationRequestRequestTypeDef,
-    _OptionalCreateAssistantAssociationRequestRequestTypeDef,
-):
-    pass
-
 
 CreateAssistantAssociationResponseTypeDef = TypedDict(
     "CreateAssistantAssociationResponseTypeDef",
@@ -357,30 +267,19 @@ CreateAssistantAssociationResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateAssistantRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAssistantRequestRequestTypeDef",
+CreateAssistantRequestRequestTypeDef = TypedDict(
+    "CreateAssistantRequestRequestTypeDef",
     {
         "name": str,
         "type": Literal["AGENT"],
+        "clientToken": NotRequired[str],
+        "description": NotRequired[str],
+        "serverSideEncryptionConfiguration": NotRequired[
+            "ServerSideEncryptionConfigurationTypeDef"
+        ],
+        "tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateAssistantRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAssistantRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "description": str,
-        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateAssistantRequestRequestTypeDef(
-    _RequiredCreateAssistantRequestRequestTypeDef, _OptionalCreateAssistantRequestRequestTypeDef
-):
-    pass
-
 
 CreateAssistantResponseTypeDef = TypedDict(
     "CreateAssistantResponseTypeDef",
@@ -390,32 +289,19 @@ CreateAssistantResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateContentRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateContentRequestRequestTypeDef",
+CreateContentRequestRequestTypeDef = TypedDict(
+    "CreateContentRequestRequestTypeDef",
     {
         "knowledgeBaseId": str,
         "name": str,
         "uploadId": str,
+        "clientToken": NotRequired[str],
+        "metadata": NotRequired[Mapping[str, str]],
+        "overrideLinkOutUri": NotRequired[str],
+        "tags": NotRequired[Mapping[str, str]],
+        "title": NotRequired[str],
     },
 )
-_OptionalCreateContentRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateContentRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "metadata": Mapping[str, str],
-        "overrideLinkOutUri": str,
-        "tags": Mapping[str, str],
-        "title": str,
-    },
-    total=False,
-)
-
-
-class CreateContentRequestRequestTypeDef(
-    _RequiredCreateContentRequestRequestTypeDef, _OptionalCreateContentRequestRequestTypeDef
-):
-    pass
-
 
 CreateContentResponseTypeDef = TypedDict(
     "CreateContentResponseTypeDef",
@@ -425,33 +311,21 @@ CreateContentResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateKnowledgeBaseRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateKnowledgeBaseRequestRequestTypeDef",
+CreateKnowledgeBaseRequestRequestTypeDef = TypedDict(
+    "CreateKnowledgeBaseRequestRequestTypeDef",
     {
         "knowledgeBaseType": KnowledgeBaseTypeType,
         "name": str,
+        "clientToken": NotRequired[str],
+        "description": NotRequired[str],
+        "renderingConfiguration": NotRequired["RenderingConfigurationTypeDef"],
+        "serverSideEncryptionConfiguration": NotRequired[
+            "ServerSideEncryptionConfigurationTypeDef"
+        ],
+        "sourceConfiguration": NotRequired["SourceConfigurationTypeDef"],
+        "tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateKnowledgeBaseRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateKnowledgeBaseRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "description": str,
-        "renderingConfiguration": "RenderingConfigurationTypeDef",
-        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
-        "sourceConfiguration": "SourceConfigurationTypeDef",
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateKnowledgeBaseRequestRequestTypeDef(
-    _RequiredCreateKnowledgeBaseRequestRequestTypeDef,
-    _OptionalCreateKnowledgeBaseRequestRequestTypeDef,
-):
-    pass
-
 
 CreateKnowledgeBaseResponseTypeDef = TypedDict(
     "CreateKnowledgeBaseResponseTypeDef",
@@ -461,29 +335,16 @@ CreateKnowledgeBaseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateSessionRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateSessionRequestRequestTypeDef",
+CreateSessionRequestRequestTypeDef = TypedDict(
+    "CreateSessionRequestRequestTypeDef",
     {
         "assistantId": str,
         "name": str,
+        "clientToken": NotRequired[str],
+        "description": NotRequired[str],
+        "tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateSessionRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateSessionRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "description": str,
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateSessionRequestRequestTypeDef(
-    _RequiredCreateSessionRequestRequestTypeDef, _OptionalCreateSessionRequestRequestTypeDef
-):
-    pass
-
 
 CreateSessionResponseTypeDef = TypedDict(
     "CreateSessionResponseTypeDef",
@@ -526,31 +387,19 @@ DeleteKnowledgeBaseRequestRequestTypeDef = TypedDict(
 DocumentTextTypeDef = TypedDict(
     "DocumentTextTypeDef",
     {
-        "highlights": List["HighlightTypeDef"],
-        "text": str,
+        "highlights": NotRequired[List["HighlightTypeDef"]],
+        "text": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredDocumentTypeDef = TypedDict(
-    "_RequiredDocumentTypeDef",
+DocumentTypeDef = TypedDict(
+    "DocumentTypeDef",
     {
         "contentReference": "ContentReferenceTypeDef",
+        "excerpt": NotRequired["DocumentTextTypeDef"],
+        "title": NotRequired["DocumentTextTypeDef"],
     },
 )
-_OptionalDocumentTypeDef = TypedDict(
-    "_OptionalDocumentTypeDef",
-    {
-        "excerpt": "DocumentTextTypeDef",
-        "title": "DocumentTextTypeDef",
-    },
-    total=False,
-)
-
-
-class DocumentTypeDef(_RequiredDocumentTypeDef, _OptionalDocumentTypeDef):
-    pass
-
 
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
@@ -639,29 +488,15 @@ GetKnowledgeBaseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetRecommendationsRequestRequestTypeDef = TypedDict(
-    "_RequiredGetRecommendationsRequestRequestTypeDef",
+GetRecommendationsRequestRequestTypeDef = TypedDict(
+    "GetRecommendationsRequestRequestTypeDef",
     {
         "assistantId": str,
         "sessionId": str,
+        "maxResults": NotRequired[int],
+        "waitTimeSeconds": NotRequired[int],
     },
 )
-_OptionalGetRecommendationsRequestRequestTypeDef = TypedDict(
-    "_OptionalGetRecommendationsRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "waitTimeSeconds": int,
-    },
-    total=False,
-)
-
-
-class GetRecommendationsRequestRequestTypeDef(
-    _RequiredGetRecommendationsRequestRequestTypeDef,
-    _OptionalGetRecommendationsRequestRequestTypeDef,
-):
-    pass
-
 
 GetRecommendationsResponseTypeDef = TypedDict(
     "GetRecommendationsResponseTypeDef",
@@ -690,124 +525,64 @@ GetSessionResponseTypeDef = TypedDict(
 HighlightTypeDef = TypedDict(
     "HighlightTypeDef",
     {
-        "beginOffsetInclusive": int,
-        "endOffsetExclusive": int,
+        "beginOffsetInclusive": NotRequired[int],
+        "endOffsetExclusive": NotRequired[int],
     },
-    total=False,
 )
 
 KnowledgeBaseAssociationDataTypeDef = TypedDict(
     "KnowledgeBaseAssociationDataTypeDef",
     {
-        "knowledgeBaseArn": str,
-        "knowledgeBaseId": str,
+        "knowledgeBaseArn": NotRequired[str],
+        "knowledgeBaseId": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredKnowledgeBaseDataTypeDef = TypedDict(
-    "_RequiredKnowledgeBaseDataTypeDef",
+KnowledgeBaseDataTypeDef = TypedDict(
+    "KnowledgeBaseDataTypeDef",
     {
         "knowledgeBaseArn": str,
         "knowledgeBaseId": str,
         "knowledgeBaseType": KnowledgeBaseTypeType,
         "name": str,
         "status": KnowledgeBaseStatusType,
+        "description": NotRequired[str],
+        "lastContentModificationTime": NotRequired[datetime],
+        "renderingConfiguration": NotRequired["RenderingConfigurationTypeDef"],
+        "serverSideEncryptionConfiguration": NotRequired[
+            "ServerSideEncryptionConfigurationTypeDef"
+        ],
+        "sourceConfiguration": NotRequired["SourceConfigurationTypeDef"],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalKnowledgeBaseDataTypeDef = TypedDict(
-    "_OptionalKnowledgeBaseDataTypeDef",
-    {
-        "description": str,
-        "lastContentModificationTime": datetime,
-        "renderingConfiguration": "RenderingConfigurationTypeDef",
-        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
-        "sourceConfiguration": "SourceConfigurationTypeDef",
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
 
-
-class KnowledgeBaseDataTypeDef(
-    _RequiredKnowledgeBaseDataTypeDef, _OptionalKnowledgeBaseDataTypeDef
-):
-    pass
-
-
-_RequiredKnowledgeBaseSummaryTypeDef = TypedDict(
-    "_RequiredKnowledgeBaseSummaryTypeDef",
+KnowledgeBaseSummaryTypeDef = TypedDict(
+    "KnowledgeBaseSummaryTypeDef",
     {
         "knowledgeBaseArn": str,
         "knowledgeBaseId": str,
         "knowledgeBaseType": KnowledgeBaseTypeType,
         "name": str,
         "status": KnowledgeBaseStatusType,
+        "description": NotRequired[str],
+        "renderingConfiguration": NotRequired["RenderingConfigurationTypeDef"],
+        "serverSideEncryptionConfiguration": NotRequired[
+            "ServerSideEncryptionConfigurationTypeDef"
+        ],
+        "sourceConfiguration": NotRequired["SourceConfigurationTypeDef"],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalKnowledgeBaseSummaryTypeDef = TypedDict(
-    "_OptionalKnowledgeBaseSummaryTypeDef",
-    {
-        "description": str,
-        "renderingConfiguration": "RenderingConfigurationTypeDef",
-        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
-        "sourceConfiguration": "SourceConfigurationTypeDef",
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
 
-
-class KnowledgeBaseSummaryTypeDef(
-    _RequiredKnowledgeBaseSummaryTypeDef, _OptionalKnowledgeBaseSummaryTypeDef
-):
-    pass
-
-
-_RequiredListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef = TypedDict(
-    "_RequiredListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
+ListAssistantAssociationsRequestRequestTypeDef = TypedDict(
+    "ListAssistantAssociationsRequestRequestTypeDef",
     {
         "assistantId": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef = TypedDict(
-    "_OptionalListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef(
-    _RequiredListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef,
-    _OptionalListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef,
-):
-    pass
-
-
-_RequiredListAssistantAssociationsRequestRequestTypeDef = TypedDict(
-    "_RequiredListAssistantAssociationsRequestRequestTypeDef",
-    {
-        "assistantId": str,
-    },
-)
-_OptionalListAssistantAssociationsRequestRequestTypeDef = TypedDict(
-    "_OptionalListAssistantAssociationsRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListAssistantAssociationsRequestRequestTypeDef(
-    _RequiredListAssistantAssociationsRequestRequestTypeDef,
-    _OptionalListAssistantAssociationsRequestRequestTypeDef,
-):
-    pass
-
 
 ListAssistantAssociationsResponseTypeDef = TypedDict(
     "ListAssistantAssociationsResponseTypeDef",
@@ -818,21 +593,12 @@ ListAssistantAssociationsResponseTypeDef = TypedDict(
     },
 )
 
-ListAssistantsRequestListAssistantsPaginateTypeDef = TypedDict(
-    "ListAssistantsRequestListAssistantsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListAssistantsRequestRequestTypeDef = TypedDict(
     "ListAssistantsRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListAssistantsResponseTypeDef = TypedDict(
@@ -844,49 +610,14 @@ ListAssistantsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListContentsRequestListContentsPaginateTypeDef = TypedDict(
-    "_RequiredListContentsRequestListContentsPaginateTypeDef",
+ListContentsRequestRequestTypeDef = TypedDict(
+    "ListContentsRequestRequestTypeDef",
     {
         "knowledgeBaseId": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListContentsRequestListContentsPaginateTypeDef = TypedDict(
-    "_OptionalListContentsRequestListContentsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListContentsRequestListContentsPaginateTypeDef(
-    _RequiredListContentsRequestListContentsPaginateTypeDef,
-    _OptionalListContentsRequestListContentsPaginateTypeDef,
-):
-    pass
-
-
-_RequiredListContentsRequestRequestTypeDef = TypedDict(
-    "_RequiredListContentsRequestRequestTypeDef",
-    {
-        "knowledgeBaseId": str,
-    },
-)
-_OptionalListContentsRequestRequestTypeDef = TypedDict(
-    "_OptionalListContentsRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListContentsRequestRequestTypeDef(
-    _RequiredListContentsRequestRequestTypeDef, _OptionalListContentsRequestRequestTypeDef
-):
-    pass
-
 
 ListContentsResponseTypeDef = TypedDict(
     "ListContentsResponseTypeDef",
@@ -897,21 +628,12 @@ ListContentsResponseTypeDef = TypedDict(
     },
 )
 
-ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef = TypedDict(
-    "ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListKnowledgeBasesRequestRequestTypeDef = TypedDict(
     "ListKnowledgeBasesRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListKnowledgeBasesResponseTypeDef = TypedDict(
@@ -941,10 +663,9 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 NotifyRecommendationsReceivedErrorTypeDef = TypedDict(
     "NotifyRecommendationsReceivedErrorTypeDef",
     {
-        "message": str,
-        "recommendationId": str,
+        "message": NotRequired[str],
+        "recommendationId": NotRequired[str],
     },
-    total=False,
 )
 
 NotifyRecommendationsReceivedRequestRequestTypeDef = TypedDict(
@@ -968,58 +689,21 @@ NotifyRecommendationsReceivedResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredQueryAssistantRequestQueryAssistantPaginateTypeDef = TypedDict(
-    "_RequiredQueryAssistantRequestQueryAssistantPaginateTypeDef",
+QueryAssistantRequestRequestTypeDef = TypedDict(
+    "QueryAssistantRequestRequestTypeDef",
     {
         "assistantId": str,
         "queryText": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalQueryAssistantRequestQueryAssistantPaginateTypeDef = TypedDict(
-    "_OptionalQueryAssistantRequestQueryAssistantPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class QueryAssistantRequestQueryAssistantPaginateTypeDef(
-    _RequiredQueryAssistantRequestQueryAssistantPaginateTypeDef,
-    _OptionalQueryAssistantRequestQueryAssistantPaginateTypeDef,
-):
-    pass
-
-
-_RequiredQueryAssistantRequestRequestTypeDef = TypedDict(
-    "_RequiredQueryAssistantRequestRequestTypeDef",
-    {
-        "assistantId": str,
-        "queryText": str,
-    },
-)
-_OptionalQueryAssistantRequestRequestTypeDef = TypedDict(
-    "_OptionalQueryAssistantRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class QueryAssistantRequestRequestTypeDef(
-    _RequiredQueryAssistantRequestRequestTypeDef, _OptionalQueryAssistantRequestRequestTypeDef
-):
-    pass
-
 
 QueryAssistantResponseTypeDef = TypedDict(
     "QueryAssistantResponseTypeDef",
@@ -1030,28 +714,15 @@ QueryAssistantResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredRecommendationDataTypeDef = TypedDict(
-    "_RequiredRecommendationDataTypeDef",
+RecommendationDataTypeDef = TypedDict(
+    "RecommendationDataTypeDef",
     {
         "document": "DocumentTypeDef",
         "recommendationId": str,
+        "relevanceLevel": NotRequired[RelevanceLevelType],
+        "relevanceScore": NotRequired[float],
     },
 )
-_OptionalRecommendationDataTypeDef = TypedDict(
-    "_OptionalRecommendationDataTypeDef",
-    {
-        "relevanceLevel": RelevanceLevelType,
-        "relevanceScore": float,
-    },
-    total=False,
-)
-
-
-class RecommendationDataTypeDef(
-    _RequiredRecommendationDataTypeDef, _OptionalRecommendationDataTypeDef
-):
-    pass
-
 
 RemoveKnowledgeBaseTemplateUriRequestRequestTypeDef = TypedDict(
     "RemoveKnowledgeBaseTemplateUriRequestRequestTypeDef",
@@ -1063,9 +734,8 @@ RemoveKnowledgeBaseTemplateUriRequestRequestTypeDef = TypedDict(
 RenderingConfigurationTypeDef = TypedDict(
     "RenderingConfigurationTypeDef",
     {
-        "templateUri": str,
+        "templateUri": NotRequired[str],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -1079,71 +749,24 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredResultDataTypeDef = TypedDict(
-    "_RequiredResultDataTypeDef",
+ResultDataTypeDef = TypedDict(
+    "ResultDataTypeDef",
     {
         "document": "DocumentTypeDef",
         "resultId": str,
+        "relevanceScore": NotRequired[float],
     },
 )
-_OptionalResultDataTypeDef = TypedDict(
-    "_OptionalResultDataTypeDef",
-    {
-        "relevanceScore": float,
-    },
-    total=False,
-)
 
-
-class ResultDataTypeDef(_RequiredResultDataTypeDef, _OptionalResultDataTypeDef):
-    pass
-
-
-_RequiredSearchContentRequestRequestTypeDef = TypedDict(
-    "_RequiredSearchContentRequestRequestTypeDef",
+SearchContentRequestRequestTypeDef = TypedDict(
+    "SearchContentRequestRequestTypeDef",
     {
         "knowledgeBaseId": str,
         "searchExpression": "SearchExpressionTypeDef",
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalSearchContentRequestRequestTypeDef = TypedDict(
-    "_OptionalSearchContentRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class SearchContentRequestRequestTypeDef(
-    _RequiredSearchContentRequestRequestTypeDef, _OptionalSearchContentRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredSearchContentRequestSearchContentPaginateTypeDef = TypedDict(
-    "_RequiredSearchContentRequestSearchContentPaginateTypeDef",
-    {
-        "knowledgeBaseId": str,
-        "searchExpression": "SearchExpressionTypeDef",
-    },
-)
-_OptionalSearchContentRequestSearchContentPaginateTypeDef = TypedDict(
-    "_OptionalSearchContentRequestSearchContentPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class SearchContentRequestSearchContentPaginateTypeDef(
-    _RequiredSearchContentRequestSearchContentPaginateTypeDef,
-    _OptionalSearchContentRequestSearchContentPaginateTypeDef,
-):
-    pass
-
 
 SearchContentResponseTypeDef = TypedDict(
     "SearchContentResponseTypeDef",
@@ -1161,51 +784,15 @@ SearchExpressionTypeDef = TypedDict(
     },
 )
 
-_RequiredSearchSessionsRequestRequestTypeDef = TypedDict(
-    "_RequiredSearchSessionsRequestRequestTypeDef",
+SearchSessionsRequestRequestTypeDef = TypedDict(
+    "SearchSessionsRequestRequestTypeDef",
     {
         "assistantId": str,
         "searchExpression": "SearchExpressionTypeDef",
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalSearchSessionsRequestRequestTypeDef = TypedDict(
-    "_OptionalSearchSessionsRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class SearchSessionsRequestRequestTypeDef(
-    _RequiredSearchSessionsRequestRequestTypeDef, _OptionalSearchSessionsRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredSearchSessionsRequestSearchSessionsPaginateTypeDef = TypedDict(
-    "_RequiredSearchSessionsRequestSearchSessionsPaginateTypeDef",
-    {
-        "assistantId": str,
-        "searchExpression": "SearchExpressionTypeDef",
-    },
-)
-_OptionalSearchSessionsRequestSearchSessionsPaginateTypeDef = TypedDict(
-    "_OptionalSearchSessionsRequestSearchSessionsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class SearchSessionsRequestSearchSessionsPaginateTypeDef(
-    _RequiredSearchSessionsRequestSearchSessionsPaginateTypeDef,
-    _OptionalSearchSessionsRequestSearchSessionsPaginateTypeDef,
-):
-    pass
-
 
 SearchSessionsResponseTypeDef = TypedDict(
     "SearchSessionsResponseTypeDef",
@@ -1219,32 +806,20 @@ SearchSessionsResponseTypeDef = TypedDict(
 ServerSideEncryptionConfigurationTypeDef = TypedDict(
     "ServerSideEncryptionConfigurationTypeDef",
     {
-        "kmsKeyId": str,
+        "kmsKeyId": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredSessionDataTypeDef = TypedDict(
-    "_RequiredSessionDataTypeDef",
+SessionDataTypeDef = TypedDict(
+    "SessionDataTypeDef",
     {
         "name": str,
         "sessionArn": str,
         "sessionId": str,
+        "description": NotRequired[str],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalSessionDataTypeDef = TypedDict(
-    "_OptionalSessionDataTypeDef",
-    {
-        "description": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class SessionDataTypeDef(_RequiredSessionDataTypeDef, _OptionalSessionDataTypeDef):
-    pass
-
 
 SessionSummaryTypeDef = TypedDict(
     "SessionSummaryTypeDef",
@@ -1259,9 +834,8 @@ SessionSummaryTypeDef = TypedDict(
 SourceConfigurationTypeDef = TypedDict(
     "SourceConfigurationTypeDef",
     {
-        "appIntegrations": "AppIntegrationsConfigurationTypeDef",
+        "appIntegrations": NotRequired["AppIntegrationsConfigurationTypeDef"],
     },
-    total=False,
 )
 
 StartContentUploadRequestRequestTypeDef = TypedDict(
@@ -1299,32 +873,19 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateContentRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateContentRequestRequestTypeDef",
+UpdateContentRequestRequestTypeDef = TypedDict(
+    "UpdateContentRequestRequestTypeDef",
     {
         "contentId": str,
         "knowledgeBaseId": str,
+        "metadata": NotRequired[Mapping[str, str]],
+        "overrideLinkOutUri": NotRequired[str],
+        "removeOverrideLinkOutUri": NotRequired[bool],
+        "revisionId": NotRequired[str],
+        "title": NotRequired[str],
+        "uploadId": NotRequired[str],
     },
 )
-_OptionalUpdateContentRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateContentRequestRequestTypeDef",
-    {
-        "metadata": Mapping[str, str],
-        "overrideLinkOutUri": str,
-        "removeOverrideLinkOutUri": bool,
-        "revisionId": str,
-        "title": str,
-        "uploadId": str,
-    },
-    total=False,
-)
-
-
-class UpdateContentRequestRequestTypeDef(
-    _RequiredUpdateContentRequestRequestTypeDef, _OptionalUpdateContentRequestRequestTypeDef
-):
-    pass
-
 
 UpdateContentResponseTypeDef = TypedDict(
     "UpdateContentResponseTypeDef",
